==> espresso_4.3.2.orig.tar.gz: espresso-4.3.2/Doc/user_guide/labels.pl <==
# LaTeX2HTML 2008 (1.71)
# Associate labels original text with physical files.


$key = q/SubSec:para/;
$external_labels{$key} = "$URL/" . q|node17.html|; 
$noresave{$key} = "$nosave";

$key = q/pw2casino_info/;
$external_labels{$key} = "$URL/" . q|node28.html|; 
$noresave{$key} = "$nosave";

$key = q/Sec:Installation/;
$external_labels{$key} = "$URL/" . q|node9.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Contacts/;
$external_labels{$key} = "$URL/" . q|node5.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:pseudo/;
$external_labels{$key} = "$URL/" . q|node24.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Examples/;
$external_labels{$key} = "$URL/" . q|node13.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:badpara/;
$external_labels{$key} = "$URL/" . q|node50.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Guidelines/;
$external_labels{$key} = "$URL/" . q|node5.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:manconf/;
$external_labels{$key} = "$URL/" . q|node10.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:LinuxPCMPI/;
$external_labels{$key} = "$URL/" . q|node14.html|; 
$noresave{$key} = "$nosave";

$key = q/Sec:para/;
$external_labels{$key} = "$URL/" . q|node15.html|; 
$noresave{$key} = "$nosave";

$key = q/Sec:Libraries/;
$external_labels{$key} = "$URL/" . q|node11.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2008 (1.71)
# labels from external_latex_labels array.


$key = q/SubSec:para/;
$external_latex_labels{$key} = q|3.2|; 
$noresave{$key} = "$nosave";

$key = q/pw2casino_info/;
$external_latex_labels{$key} = q|5.3|; 
$noresave{$key} = "$nosave";

$key = q/Sec:Installation/;
$external_latex_labels{$key} = q|2.2|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Contacts/;
$external_latex_labels{$key} = q|1.3|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:pseudo/;
$external_latex_labels{$key} = q|4.4|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Examples/;
$external_latex_labels{$key} = q|2.6|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:badpara/;
$external_latex_labels{$key} = q|10.4|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Guidelines/;
$external_latex_labels{$key} = q|1.3.1|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:manconf/;
$external_latex_labels{$key} = q|2.3.1|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:LinuxPCMPI/;
$external_latex_labels{$key} = q|2.7.6|; 
$noresave{$key} = "$nosave";

$key = q/Sec:para/;
$external_latex_labels{$key} = q|3|; 
$noresave{$key} = "$nosave";

$key = q/Sec:Libraries/;
$external_latex_labels{$key} = q|2.4|; 
$noresave{$key} = "$nosave";

1;

==> espresso_5.0.2.orig.tar.gz: espresso-5.0.2/Doc/user_guide/labels.pl <==
# LaTeX2HTML 2002-2-1 (1.71)
# Associate labels original text with physical files.


$key = q/SubSec:para/;
$external_labels{$key} = "$URL/" . q|node17.html|; 
$noresave{$key} = "$nosave";

$key = q/Sec:Installation/;
$external_labels{$key} = "$URL/" . q|node9.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Contacts/;
$external_labels{$key} = "$URL/" . q|node4.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Terms/;
$external_labels{$key} = "$URL/" . q|node6.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Examples/;
$external_labels{$key} = "$URL/" . q|node13.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Guidelines/;
$external_labels{$key} = "$URL/" . q|node5.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:manconf/;
$external_labels{$key} = "$URL/" . q|node10.html|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:LinuxPCMPI/;
$external_labels{$key} = "$URL/" . q|node14.html|; 
$noresave{$key} = "$nosave";

$key = q/Sec:para/;
$external_labels{$key} = "$URL/" . q|node15.html|; 
$noresave{$key} = "$nosave";

$key = q/Sec:Libraries/;
$external_labels{$key} = "$URL/" . q|node11.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2002-2-1 (1.71)
# labels from external_latex_labels array.


$key = q/SubSec:para/;
$external_latex_labels{$key} = q|3.2|; 
$noresave{$key} = "$nosave";

$key = q/Sec:Installation/;
$external_latex_labels{$key} = q|2.2|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Contacts/;
$external_latex_labels{$key} = q|1.2|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Terms/;
$external_latex_labels{$key} = q|1.4|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Examples/;
$external_latex_labels{$key} = q|2.6|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:Guidelines/;
$external_latex_labels{$key} = q|1.3|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:manconf/;
$external_latex_labels{$key} = q|2.3.1|; 
$noresave{$key} = "$nosave";

$key = q/SubSec:LinuxPCMPI/;
$external_latex_labels{$key} = q|2.7.6|; 
$noresave{$key} = "$nosave";

$key = q/Sec:para/;
$external_latex_labels{$key} = q|3|; 
$noresave{$key} = "$nosave";

$key = q/Sec:Libraries/;
$external_latex_labels{$key} = q|2.4|; 
$noresave{$key} = "$nosave";

1;
